import { select, json, tree, hierarchy, linkHorizontal } from 'd3';

const svg = select('svg');
const width = document.body.clientWidth;;
const height = document.body.clientHeight;

const margin = { top:20, right:50, bottom:10, left:30};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const treeLayout = tree()
	.size([innerHeight, innerWidth]);

const g = svg
    .attr('width', width)
    .attr('height', height)
	.append('g')
		.attr('transform', `translate(${margin.left},${margin.top})`);

json('data.json')
	.then(data => {
		const root = hierarchy(data);
  	const links = treeLayout(root).links();
  	const linkPathGenerator = linkHorizontal()
			.x(d => d.y)
    	.y(d => d.x);
		
  	g.selectAll('path').data(links)
  		.enter().append('path')
  			.attr('d', linkPathGenerator)
  			.attr("class", "link")
    		.style("stroke", function(d) { return 'grey'; });
  
  	var node = g.selectAll(".node")
    	.data(root.descendants())
  		.enter().append("g")
    		.attr("class", function(d) { 
      		return "node" + 
        	(d.children ? " node--internal" : " node--leaf"); })
    		.attr("transform", function(d) { 
      		return "translate(" + d.y + "," + d.x + ")"; });
  
  	node.append("circle")
  		.attr("r", d => 20 - d.depth*7)
  		.style("stroke", function(d) { return 'steelBlue'; })
  		.style("fill", function(d) { return 'orange'; });
  		// .attr("r", function(d) { return d.data.value; })
  		// .style("stroke", function(d) { return d.data.type; })
  		// .style("fill", function(d) { return d.data.level; });
  
  	g.selectAll('text').data(root.descendants())
  		.enter().append('text')
  			.attr('x', d => d.y + 20)
  			.attr('y', d => d.x - 10)
  			.attr('font-size', d => 2.0 - d.depth + 'em')
  			.text(d => d.data.data.id);
});